/*------------------------------------------------------------------------------

WRAPI32.H

  This header file is designed for compilation with WRAPI32.LIB not WRAPI.C.

  For 16-bit applications, please use the other demo supplied (generic 16/32
  bit using run-time linking).

  For detailed information on these functions, see 
	http://www.winradio.com/home/sdk.htm

------------------------------------------------------------------------------*/

#ifndef _WRAPI_H_
#define _WRAPI_H_

#include <windows.h>

// WiNRADiO Information Features (capabilities)

#define RIF_USVERSION   0x00000001  // set if hardware is US version
#define RIF_DSP			0x00000002	// set if DSP is present
#define RIF_LSBUSB		0x00000004	// set if receiver as CW/LSB/USB instead of SSB
#define RIF_CWIFSHIFT	0x00000008	// set if receiver uses IFShift in CW (not BFOOffset)

// WiNRADiO Modes

#define RMD_CW	0         
#define RMD_AM	1
#define RMD_FMN	2
#define RMD_FMW	3
#define RMD_LSB	4
#define RMD_USB	5

// WiNRADiO Hardware Versions

#define RHV_1000a	0x0100		// older WR-1000 series	
#define RHV_1000b	0x010a		// standard WR-1000 series
#define RHV_1500	0x0132		
#define RHV_3000	0x0200		// Spectrum Monitor series
#define RHV_3100	0x020a

// WiNRADiO Hardware Interfaces 

#define RHI_ISA		0
#define RHI_SERIAL	1
#define RHI_PCMCIA	2	

// WiNRADiO Audio Sources 

#define RAS_RADIO	0
#define RAS_DSP		1

// WiNRADiO DSP input Sources 

#define	RDS_RADIO	0		// DSP input from demodulated audio output
#define RDS_DATA	1		// DSP input from FM discriminator

// WiNRADiO Wave formats 

#define RWF_8KHZ	0x00000001	//  8 kHz sampling rate
#define RWF_11KHZ	0x00000002	// 11 kHz sampling rate
#define RWF_16KHZ	0x00000004	// 16 kHz sampling rate

#define RWF_8BIT	0x00010000	// 8 bits per sample
#define RWF_16BIT	0x00020000	// 16 bits per sample

#define RWF_MONO	0x01000000	// single channel sampling

// WiNRADiO notification Messages 

#define RM_DSPREQ		0x7f00	// user defined request
#define RM_DMAACKWRITE	0x7f01	// DMA write operation finished
#define RM_DMAACKREAD	0x7f02	// DMA read operation finished
#define RM_DMAREQWRITE	0x7f03	// request DMA write
#define RM_DMAREQREAD	0x7f04	// request DMA read
#define RM_DMAPAUSED	0x7f05	// DMA has been paused
#define RM_DMARESUMED	0x7f06	// DMA has resumed

  // sent to any windows that have called EnableRadioNotification
#define RM_RADIOADDED	0x7f10	// a PCMCIA WiNRADiO has been inserted 
#define RM_RADIOREMOVED	0x7f11  // an External WiNRADiO has been removed 


#ifdef __cplusplus
extern "C" {
#endif

// RADIOINFO structure for GetRadioDeviceInfo

typedef int FAR *LPMODELIST;

typedef struct tRADIOINFO
{
    DWORD       dwSize;				// size of structure (must be set before calling GetRadioDeviceInfo) 
    DWORD       dwFeatures;			// bit flags for extra features (RIF_XXX)
    WORD        wAPIVer;			// driver version
    WORD        wHWVer;				// hardware version (RHV_XXX)
    DWORD       dwMinFreq;			// minimum frequency receiver can tune to
    DWORD       dwMaxFreq;			// maximum frequency receiver can tune to 
    int         iFreqRes;			// resolution of receiver in Hz 
    int         iNumModes;			// number of modes that can be set 
    int         iMaxVolume;			// maximum volume level 
    int         iMaxBFO;			// maximum BFO offset range (+/- in Hz) 
    int         iMaxFMScanRate;		// maximum scan rate for FM scanning/sweeping
    int         iMaxAMScanRate;		// maximum scan rate for AM scanning/sweeping
    int         iHWInterface;		// physical interface radio is connected to (RHI_XXX)
	int			iDeviceNum;			// logical radio device number	
    int         iNumSources;        // number of selectable audio sources
    int         iMaxIFShift;        // maximum IF shift
    DWORD       dwWaveFormats;      // bit array of supported rec/play formats (RWF_XXX)
    int			iDSPSources;		// number of selectable DSP input sources 
    LPMODELIST  lpSupportedModes;   // list of available modes (length specified by iNumModes)
	int			dwMaxFreqkHz;		// same as dwMaxFreq, but in kHz
} RADIOINFO, *PRADIOINFO, FAR *LPRADIOINFO;

typedef struct tDSPHDR
{
    PVOID lpData;
    DWORD dwBufferLength;
    DWORD dwBytesTransferred;
    DWORD dwUser;
    DWORD fDone;
} DSPHDR, *PDSPHDR, FAR *LPDSPHDR;

// exported function prototypes

int	WINAPI OpenRadioDevice(int iDeviceNum);
BOOL WINAPI CloseRadioDevice(int hRadio);
int WINAPI GetRadioDeviceInfo(int hRadio, LPRADIOINFO lpInfo);
DWORD WINAPI GetSignalStrength(int hRadio);

BOOL WINAPI SetFrequency(int hRadio, DWORD dwFreq);
BOOL WINAPI SetMode(int hRadio, int iMode);
BOOL WINAPI SetVolume(int hRadio, int iVolume);
BOOL WINAPI SetAtten(int hRadio, BOOL fAtten);
BOOL WINAPI SetMute(int hRadio, BOOL fMute);
BOOL WINAPI SetPower(int hRadio, BOOL fPower);
BOOL WINAPI SetScanMode(int hRadio, BOOL fScanMode);
BOOL WINAPI SetBFOOffset(int hRadio, int iBFOOffset);
BOOL WINAPI SetIFShift(int hRadio, int iIFShift);
BOOL WINAPI SetAudioSource(int hRadio, int iSource);
BOOL WINAPI SetDSPSource(int hRadio, int iSource);

DWORD WINAPI GetFrequency(int hRadio);
int WINAPI GetMode(int hRadio);
int WINAPI GetVolume(int hRadio);
BOOL WINAPI GetAtten(int hRadio);
BOOL WINAPI GetMute(int hRadio);
BOOL WINAPI GetPower(int hRadio);
BOOL WINAPI GetScanMode(int hRadio);
int WINAPI GetBFOOffset(int hRadio);
int WINAPI GetIFShift(int hRadio);
int WINAPI GetAudioSource(int hRadio);
int WINAPI GetDSPSource(int hRadio);

// DSP API functions

BOOL WINAPI dspOpen(int hRadio, PVOID lpBootCode, HWND hWindow);
BOOL WINAPI dspClose(int hRadio);
BOOL WINAPI dspSendByte(int hRadio, BYTE bData);
BOOL WINAPI dspReadByte(int hRadio, LPBYTE lpbData);
BOOL WINAPI dspOutWrite(int hRadio, LPDSPHDR lpDSPHeader, int cbDSPHeader);
BOOL WINAPI dspInAddBuffer(int hRadio, LPDSPHDR lpDSPHeader, int cbDSPHeader);
BOOL WINAPI dspPause(int hRadio);
BOOL WINAPI dspResume(int hRadio);
BOOL WINAPI	dspOutReset(int hRadio);
BOOL WINAPI dspInReset(int hRadio);

int WINAPI dspInOpen(int hRadio, DWORD dwWaveFormat, HWND hWindow);
int WINAPI dspOutOpen(int hRadio, DWORD dwWaveFormat, HWND hWindow);

// miscellaneous API functions 

BOOL WINAPI EnableRadioNotification(HWND hWindow, BOOL fEnabled);

LPSTR WINAPI GetModeStringA(int hRadio, int iMode, LPSTR lpBuffer, int cbMaxLen);
LPWSTR WINAPI GetModeStringW(int hRadio, int iMode, LPWSTR lpBuffer, int cbMaxLen);

#ifdef UNICODE
#define GetModeString	GetModeStringW
#else
#define GetModeString	GetModeStringA
#endif

#ifdef __cplusplus
}
#endif

#endif 
